==> openfetion_1.6.1.orig.tar.gz: openfetion-1.6.1/include/fx_history.h <==
/***************************************************************************
 *   Copyright (C) 2010 by lwp                                             *
 *   levin108@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef FX_HISTORY_H
#define FX_HISTORY_H

extern FxHistory* fx_history_new(FxMain* fxmain , const char* userid , const char* name);

extern void fx_history_initialize(FxHistory* fxhistory);

extern void fx_history_bind(FxHistory* fxhistory , int count);

extern GtkTreeModel* fx_history_create_count_model();

extern void fx_history_on_close_clicked(GtkWidget* widget , gpointer data);

extern void fx_history_on_refresh_clicked(GtkWidget* widget , gpointer data);

#endif

==> openfetion_1.8-3.tar.gz: openfetion-1.8/include/fx_history.h <==
/***************************************************************************
 *   Copyright (C) 2010 by lwp                                             *
 *   levin108@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef FX_HISTORY_H
#define FX_HISTORY_H

extern FxHistory* fx_history_new(FxMain* fxmain , const char* userid , const char* name);

extern void fx_history_initialize(FxHistory* fxhistory);

extern void fx_history_bind(FxHistory* fxhistory , FxList *list);

extern GtkTreeModel* fx_history_create_count_model();

extern void fx_history_on_close_clicked(GtkWidget* UNUSED(widget) , gpointer data);

extern void fx_history_on_refresh_clicked(GtkWidget* UNUSED(widget) , gpointer data);

extern void fx_history_on_today_clicked(GtkWidget* UNUSED(widget) , gpointer data);

extern void fx_history_on_yestorday_clicked(GtkWidget* UNUSED(widget) , gpointer data);

extern void fx_history_on_month_clicked(GtkWidget* UNUSED(widget) , gpointer data);

extern void fx_history_on_all_clicked(GtkWidget* UNUSED(widget) , gpointer data);

extern void fx_history_on_export_clicked(GtkWidget* UNUSED(widget) , gpointer data);

#endif
